@@ -221,17 +221,14 @@ static grib_smart_table* load_table(grib_accessor_smart_table* self)
     grib_smart_table* t    = NULL;
     grib_smart_table* next = NULL;
     char* filename         = 0;
-    char name[2048]        = {0,};
     char recomposed[1024] = {0,};
     char localRecomposed[1024] = {0,};
     char* localFilename        = 0;
     char extraRecomposed[1024] = {0,};
     char* extraFilename  = 0;
-    char localName[2048] = {0,};
     char masterDir[1024] = {0,};
     char localDir[1024] = {0,};
     char extraDir[1024] = {0,};
-    char extraTable[2048] = {0,};
     size_t len = 1024;
 
     if (self->masterDir != NULL) {
@@ -249,6 +246,7 @@ static grib_smart_table* load_table(grib_accessor_smart_table* self)
     }
 
     if (*masterDir != 0) {
+        char name[2048] = {0,};
         sprintf(name, "%s/%s", masterDir, self->tablename);
         grib_recompose_name(h, NULL, name, recomposed, 0);
         filename = grib_context_full_defs_path(c, recomposed);
@@ -259,12 +257,14 @@ static grib_smart_table* load_table(grib_accessor_smart_table* self)
     }
 
     if (*localDir != 0) {
+        char localName[2048] = {0,};
         sprintf(localName, "%s/%s", localDir, self->tablename);
         grib_recompose_name(h, NULL, localName, localRecomposed, 0);
         localFilename = grib_context_full_defs_path(c, localRecomposed);
     }
 
     if (*extraDir != 0) {
+        char extraTable[2048] = {0,};
         sprintf(extraTable, "%s/%s", extraDir, self->extraTable);
         grib_recompose_name(h, NULL, extraTable, extraRecomposed, 0);
         extraFilename = grib_context_full_defs_path(c, extraRecomposed);
@@ -281,7 +281,7 @@ static grib_smart_table* load_table(grib_accessor_smart_table* self)
         next = next->next;
     }
 
-    size = (1UL << self->widthOfCode); /* 2 ^ self->widthOfCode */
+    size = (1ULL << self->widthOfCode); /* 2 ^ self->widthOfCode - 64 bits */
 
     t                  = (grib_smart_table*)grib_context_malloc_clear_persistent(c, sizeof(grib_smart_table));
     t->entries         = (grib_smart_table_entry*)grib_context_malloc_clear_persistent(c, size * sizeof(grib_smart_table_entry));
@@ -313,7 +313,7 @@ static int grib_load_smart_table(grib_context* c, const char* filename,
     int numberOfColumns;
     int code;
 
-    grib_context_log(c, GRIB_LOG_DEBUG, "Loading code table form %s", filename);
+    grib_context_log(c, GRIB_LOG_DEBUG, "Loading code table from %s", filename);
 
     f = codes_fopen(filename, "r");
     if (!f)
@@ -358,11 +358,6 @@ static int grib_load_smart_table(grib_context* c, const char* filename,
         while (*p != '\0' && *p != '|')
             p++;
 
-        if (!p) {
-            grib_context_log(c, GRIB_LOG_ERROR, "Invalid entry in file %s: line %d", filename, lineNumber);
-            continue; /* skip this line */
-        }
-
         *p = 0;
 
         code = atol(s);
@@ -372,10 +367,6 @@ static int grib_load_smart_table(grib_context* c, const char* filename,
         while (*p != '\0' && *p != '|')
             p++;
 
-        if (!p) {
-            grib_context_log(c, GRIB_LOG_ERROR, "Invalid entry in file %s: line %d", filename, lineNumber);
-            continue; /* skip this line */
-        }
         *p = 0;
 
         numberOfColumns = 0;
@@ -407,19 +398,24 @@ void grib_smart_table_delete(grib_context* c)
         int k;
 
         for (i = 0; i < t->numberOfEntries; i++) {
-            grib_context_free_persistent(c, t->entries[i].abbreviation);
+            if (t->entries[i].abbreviation)
+                grib_context_free_persistent(c, t->entries[i].abbreviation);
             for (k = 0; k < MAX_SMART_TABLE_COLUMNS; k++) {
                 if (t->entries[i].column[k])
                     grib_context_free_persistent(c, t->entries[i].column[k]);
             }
-            grib_context_free_persistent(c, &(t->entries[i]));
         }
+        grib_context_free_persistent(c, t->entries);
         grib_context_free_persistent(c, t->filename[0]);
         if (t->filename[1])
             grib_context_free_persistent(c, t->filename[1]);
+        if (t->filename[2])
+            grib_context_free_persistent(c, t->filename[2]);
         grib_context_free_persistent(c, t->recomposed_name[0]);
         if (t->recomposed_name[1])
             grib_context_free_persistent(c, t->recomposed_name[1]);
+        if (t->recomposed_name[2])
+            grib_context_free_persistent(c, t->recomposed_name[2]);
         grib_context_free_persistent(c, t);
         t = s;
     }
@@ -534,7 +530,7 @@ static int value_count(grib_accessor* a, long* count)
         return err;
 
     *count = self->tableCodesSize;
-    return err;
+    return GRIB_SUCCESS;
 }
 
 static void destroy(grib_context* context, grib_accessor* a)
@@ -573,7 +569,7 @@ static int unpack_long(grib_accessor* a, long* val, size_t* len)
 
     if (*len < self->tableCodesSize) {
         grib_context_log(a->context, GRIB_LOG_ERROR,
-                         " wrong size (%ld) for %s it contains %d values ", *len, a->name, self->tableCodesSize);
+                         "Wrong size (%lu) for %s it contains %lu values", *len, a->name, self->tableCodesSize);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
