@@ -38,11 +38,12 @@ extern "C" {
 #define GRIB_INLINE
 #endif
 
+/* See ECC-670 */
 #if IS_BIG_ENDIAN
 #if GRIB_MEM_ALIGN
-#define FAST_BIG_ENDIAN 0
-#else
 #define FAST_BIG_ENDIAN 1
+#else
+#define FAST_BIG_ENDIAN 0
 #endif
 #endif
 
@@ -903,7 +904,7 @@ struct grib_handle
     long missingValueLong;
     double missingValueDouble;
     ProductKind product_kind;
-    grib_trie* bufr_elements_table;
+    /* grib_trie* bufr_elements_table; */
 };
 
 struct grib_multi_handle
@@ -1095,7 +1096,7 @@ struct grib_context
     grib_hash_array_value* hash_array[MAX_NUM_HASH_ARRAY];
     grib_trie* def_files;
     grib_string_list* blocklist;
-    int ieee_packing;
+    int ieee_packing; /* 32 or 64 */
     int bufrdc_mode;
     int bufr_set_to_missing_if_out_of_range;
     int bufr_multi_element_constant_arrays;
@@ -1541,7 +1542,7 @@ struct grib_smart_table
 };
 
 
-#if GRIB_TIMER
+#if ECCODES_TIMER
 typedef struct grib_timer
 {
     struct timeval start_;
