@@ -252,6 +252,7 @@ static int grib_db_column_copy_from_handle(grib_handle* h, grib_db* db, int i)
 }
 
 /* --------------- grib_db functions ------------------*/
+#if 0
 grib_db* grib_db_new_from_files(grib_context* c, char* filenames[],
                                 int nfiles, char** keys, int nkeys, int* err)
 {
@@ -269,7 +270,7 @@ grib_db* grib_db_new_from_files(grib_context* c, char* filenames[],
     }
 
     db = grib_db_new_from_file(c, filenames[0], keys, nkeys, err);
-    if (!db || err != GRIB_SUCCESS)
+    if (!db || *err != GRIB_SUCCESS)
         return db;
 
     *err = GRIB_SUCCESS;
@@ -307,6 +308,7 @@ grib_db* grib_db_new_from_file(grib_context* c, char* filename,
 
     return db;
 }
+#endif
 
 static grib_db* grib_db_create_from_keys(grib_context* c, char** keys, int nkeys, int* err)
 {
@@ -385,7 +387,7 @@ grib_query* grib_db_new_query(grib_context* c, const char* where_string,
     grib_query* q = 0;
 
     if (!c)
-        grib_context_get_default();
+        c = grib_context_get_default();
 
     q = (grib_query*)grib_context_malloc(c, sizeof(grib_query));
 
@@ -625,8 +627,7 @@ static grib_order_by* grib_db_new_order_by(grib_context* c, char* obstr)
     ob->mode  = 0;
     ob->next  = 0;
 
-    if (z)
-        t1 = strtok(z, ",");
+    t1 = strtok(z, ",");
 
     while (t1) {
         grib_trim(&t1);
@@ -636,7 +637,7 @@ static grib_order_by* grib_db_new_order_by(grib_context* c, char* obstr)
             p++;
         mode = mode_default;
         if (p != t2) {
-            while (*p == ' ' && *p != '\0')
+            while (*p == ' ')
                 p++;
             if (*p != '\0') {
                 *(p - 1) = '\0';
@@ -904,7 +905,7 @@ static void grib_db_delete_fields(grib_fieldset* set)
 static void grib_trim(char** x)
 {
     char* p = 0;
-    while (**x == ' ' && **x != '\0')
+    while (**x == ' ')
         (*x)++;
     if (**x == '\0')
         return;
