@@ -82,6 +82,7 @@ static void init_class(grib_iterator_class* c)
 }
 /* END_CLASS_IMP */
 
+#define ITER "Lambert conformal Geoiterator"
 #define EPSILON 1.0e-10
 
 #ifndef M_PI
@@ -205,12 +206,12 @@ static int init_sphere(grib_handle* h,
     /* Allocate latitude and longitude arrays */
     self->lats = (double*)grib_context_malloc(h->context, nv * sizeof(double));
     if (!self->lats) {
-        grib_context_log(h->context, GRIB_LOG_ERROR, "Error allocating %ld bytes", nv * sizeof(double));
+        grib_context_log(h->context, GRIB_LOG_ERROR, "%s: Error allocating %ld bytes", ITER, nv * sizeof(double));
         return GRIB_OUT_OF_MEMORY;
     }
     self->lons = (double*)grib_context_malloc(h->context, nv * sizeof(double));
     if (!self->lats) {
-        grib_context_log(h->context, GRIB_LOG_ERROR, "Error allocating %ld bytes", nv * sizeof(double));
+        grib_context_log(h->context, GRIB_LOG_ERROR, "%s: Error allocating %ld bytes", ITER, nv * sizeof(double));
         return GRIB_OUT_OF_MEMORY;
     }
 
@@ -302,7 +303,7 @@ static int init_oblate(grib_handle* h,
     } else {
         con = latFirstInRadians * ns;
         if (con <= 0) {
-            grib_context_log(h->context, GRIB_LOG_ERROR, "Point cannot be projected");
+            grib_context_log(h->context, GRIB_LOG_ERROR, "%s: Point cannot be projected: latFirstInRadians=%g", ITER, latFirstInRadians);
             return GRIB_GEOCALCULUS_PROBLEM;
         }
         rh1 = 0;
@@ -316,12 +317,12 @@ static int init_oblate(grib_handle* h,
     /* Allocate latitude and longitude arrays */
     self->lats = (double*)grib_context_malloc(h->context, nv * sizeof(double));
     if (!self->lats) {
-        grib_context_log(h->context, GRIB_LOG_ERROR, "Error allocating %ld bytes", nv * sizeof(double));
+        grib_context_log(h->context, GRIB_LOG_ERROR, "%s: Error allocating %ld bytes", ITER, nv * sizeof(double));
         return GRIB_OUT_OF_MEMORY;
     }
     self->lons = (double*)grib_context_malloc(h->context, nv * sizeof(double));
     if (!self->lats) {
-        grib_context_log(h->context, GRIB_LOG_ERROR, "Error allocating %ld bytes", nv * sizeof(double));
+        grib_context_log(h->context, GRIB_LOG_ERROR, "%s: Error allocating %ld bytes", ITER, nv * sizeof(double));
         return GRIB_OUT_OF_MEMORY;
     }
 
@@ -351,7 +352,8 @@ static int init_oblate(grib_handle* h,
                 ts     = pow((rh1 / (earthMajorAxisInMetres * F)), con);
                 latRad = compute_phi(e, ts, &err);
                 if (err) {
-                    grib_context_log(h->context, GRIB_LOG_ERROR, "Failed to compute the latitude angle, phi2, for the inverse");
+                    grib_context_log(h->context, GRIB_LOG_ERROR,
+                                     "%s: Failed to compute the latitude angle, phi2, for the inverse", ITER);
                     grib_context_free(h->context, self->lats);
                     grib_context_free(h->context, self->lons);
                     return err;
@@ -414,7 +416,7 @@ static int init(grib_iterator* iter, grib_handle* h, grib_arguments* args)
     }
 
     if (iter->nv != nx * ny) {
-        grib_context_log(h->context, GRIB_LOG_ERROR, "Wrong number of points (%ld!=%ldx%ld)", iter->nv, nx, ny);
+        grib_context_log(h->context, GRIB_LOG_ERROR, "%s: Wrong number of points (%ld!=%ldx%ld)", ITER, iter->nv, nx, ny);
         return GRIB_WRONG_GRID;
     }
 
@@ -446,7 +448,7 @@ static int init(grib_iterator* iter, grib_handle* h, grib_arguments* args)
     /* Standard Parallels cannot be equal and on opposite sides of the equator */
     if (fabs(Latin1InDegrees + Latin2InDegrees) < EPSILON) {
         grib_context_log(h->context, GRIB_LOG_ERROR,
-                         "Cannot have equal latitudes for standard parallels on opposite sides of equator");
+                         "%s: Cannot have equal latitudes for standard parallels on opposite sides of equator", ITER);
         return GRIB_WRONG_GRID;
     }
 
@@ -480,7 +482,7 @@ static int init(grib_iterator* iter, grib_handle* h, grib_arguments* args)
     iter->e = -1;
 
     /* Apply the scanning mode flags which may require data array to be transformed */
-    err = transform_iterator_data(h, iter->data,
+    err = transform_iterator_data(h->context, iter->data,
                                   iScansNegatively, jScansPositively, jPointsAreConsecutive, alternativeRowScanning,
                                   iter->nv, nx, ny);
     return err;
