@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -9,7 +9,8 @@
 #
 
 . ./include.sh
-
+set -u
+label="grib_compare_test"
 REDIRECT=/dev/null
 
 infile="${data_dir}/regular_latlon_surface.grib1"
@@ -25,25 +26,42 @@ ${tools_dir}/grib_compare -b indicatorOfParameter,paramId,shortName $infile $out
 # ----------------------------------------
 infile=${data_dir}/v.grib2
 for i in 1 2 3; do
-  ${tools_dir}/grib_copy -wcount=$i $infile temp_comp.$i
+  ${tools_dir}/grib_copy -wcount=$i $infile temp.$label.$i
 done
-cat temp_comp.1 temp_comp.2 temp_comp.3 > temp_comp.123
-cat temp_comp.3 temp_comp.2 temp_comp.1 > temp_comp.321
+cat temp.$label.2 temp.$label.1 temp.$label.3 > temp.$label.213
+cat temp.$label.3 temp.$label.2 temp.$label.1 > temp.$label.321
 
 # Compare files in which the messages are not in the same order
-${tools_dir}/grib_compare -r temp_comp.123 temp_comp.321
+${tools_dir}/grib_compare -r temp.$label.213 temp.$label.321
 
-rm -f temp_comp.1 temp_comp.2 temp_comp.3 temp_comp.123 temp_comp.321
+rm -f temp.$label.1 temp.$label.2 temp.$label.3 temp.$label.213 temp.$label.321
 
-# ----------------------------------------
+# ----------------------------------------------
 # GRIB-797: test last argument being a directory
-# ----------------------------------------
-temp_dir=tempdir.grib_compare
-mkdir -p $temp_dir
+# ----------------------------------------------
+temp_dir=tempdir.$label
+rm -rf $temp_dir
+mkdir $temp_dir
 cp $infile $temp_dir
 ${tools_dir}/grib_compare $infile  $temp_dir
 rm -rf $temp_dir
 
+# ----------------------------------------
+# ECC-1350: First arg is a directory
+# ----------------------------------------
+temp_dir=tempdir.$label
+temp_err=temp.$label.err
+rm -rf $temp_dir
+mkdir $temp_dir
+set +e
+${tools_dir}/grib_compare $temp_dir $temp_dir 2>$temp_err
+status=$?
+set -e
+[ $status -eq 1 ]
+grep -q "ERROR:.*Is a directory" $temp_err
+rm -rf $temp_dir
+
+
 # ----------------------------------------
 # ECC-245: blacklist and 2nd order packing
 # ----------------------------------------
