@@ -64,8 +64,9 @@ if [ $ECCODES_ON_WINDOWS -eq 0 ]; then
     set -e
     if [ $stat -eq 0 ]; then
         have_netcdf4=1
-        res=`${tools_dir}/grib_get -TA -p identifier,versionNumberOfSuperblock $tempNetcdf`
-        [ "$res" = "HDF5 0" ]
+        ${tools_dir}/grib_dump -TA -O $tempNetcdf
+        res=`${tools_dir}/grib_get -TA -p identifier $tempNetcdf`
+        [ "$res" = "HDF5" ]
     fi
 fi
 
@@ -77,7 +78,7 @@ grib_files="\
  regular_gaussian_surface.grib1 \
  missing.grib2"
 
-ncf_types="NC_SHORT NC_INT NC_FLOAT NC_DOUBLE"
+ncf_types="NC_INT NC_FLOAT NC_DOUBLE"
 
 # Go thru all the specified GRIB files and convert them to NetCDF
 for dt in $ncf_types; do
