@@ -11,6 +11,8 @@
 #include <assert.h>
 #include "grib_api_internal.h"
 
+#define STR_EQUAL(s1, s2) (strcmp((s1), (s2)) == 0)
+
 int assertion_caught = 0;
 
 typedef enum
@@ -45,6 +47,15 @@ static void test_get_git_sha1()
     printf("Testing: test_get_git_sha1... %s\n", sha1);
 }
 
+static void test_get_build_date()
+{
+    const char* bdate = codes_get_build_date();
+    Assert(bdate != NULL);
+    /* Should be of the format YYYY.MM.DD or empty (not implemented) */
+    Assert( strlen(bdate) == 0 || isdigit(bdate[0]) );
+    printf("Testing: test_get_build_date... %s\n", bdate);
+}
+
 static void test_grib_nearest_smaller_ibmfloat()
 {
     printf("Testing: test_grib_nearest_smaller_ibmfloat...\n");
@@ -1461,7 +1472,8 @@ static void test_concept_condition_strings()
 {
     int err           = 0;
     char result[1024] = {0,};
-    grib_handle* h = grib_handle_new_from_samples(0, "GRIB2");
+    grib_context* context = NULL;
+    grib_handle* h = grib_handle_new_from_samples(context, "GRIB2");
 
     printf("Testing: test_concept_condition_strings...\n");
 
@@ -1475,7 +1487,6 @@ static void test_concept_condition_strings()
 
     err = get_concept_condition_string(h, "gridType", NULL, result);
     Assert(!err);
-    /*printf("%s\n", result);*/
     Assert(strcmp(result, "gridDefinitionTemplateNumber=0,PLPresent=0") == 0);
 
     err = get_concept_condition_string(h, "stepType", NULL, result);
@@ -1485,10 +1496,58 @@ static void test_concept_condition_strings()
     grib_handle_delete(h);
 }
 
+static void test_trimming()
+{
+    char a[] = " Standing  ";
+    char b[] = "  Weeping ";
+    char c[] = "  Silhouette ";
+    char d[] = " The Forest Of October  ";
+    char e[] = "\t\n Apostle In Triumph \r ";
+    char* pA = a;
+    char* pB = b;
+    char* pC = c;
+    char* pD = d;
+    char* pE = e;
+
+    printf("Testing: test_trimming...\n");
+
+    lrtrim(&pA, 0, 1); /*right only*/
+    assert( strcmp(pA, " Standing")==0 );
+
+    lrtrim(&pB, 1, 0); /*left only*/
+    assert( strcmp(pB, "Weeping ")==0 );
+
+    lrtrim(&pC, 1, 1); /*both ends*/
+    assert( strcmp(pC, "Silhouette")==0 );
+
+    lrtrim(&pD, 1, 1); /*make sure other spaces are not removed*/
+    assert( strcmp(pD, "The Forest Of October")==0 );
+
+    lrtrim(&pE, 1, 1); /* Other chars */
+    assert( strcmp(pE, "Apostle In Triumph")==0 );
+}
+
+static void test_gribex_mode()
+{
+    grib_context* c = grib_context_get_default();
+    printf("Testing: test_gribex_mode...\n");
+
+    assert( grib_get_gribex_mode(c) == 0 ); /* default is OFF */
+    grib_gribex_mode_on(c);
+    assert( grib_get_gribex_mode(c) == 1 );
+    grib_gribex_mode_off(c);
+    assert( grib_get_gribex_mode(c) == 0 );
+}
+
 int main(int argc, char** argv)
 {
     /*printf("Doing unit tests. ecCodes version = %ld\n", grib_get_api_version());*/
+    
+    test_trimming();
+
     test_get_git_sha1();
+    test_get_build_date();
+    test_gribex_mode();
 
     test_concept_condition_strings();
 
